/******************************************************************************/
/* Files to Include                                                           */
/******************************************************************************/

//#include <p30Fxxxx.h>      /* Device header file                              */
#include <p30F6014A.h>
#include <stdint.h>        /* Includes uint16_t definition                    */
#include <stdbool.h>       /* Includes true/false definition                  */
#include <math.h>
#include <stdio.h>
#include <string.h>

#include "e_init_port.h"
#include "e_led.h"
#include "e_motors.h"
#include "e_agenda.h"
#include "e_ad_conv.h"
#include "e_prox.h"
#include "e_acc.h"
#include "e_epuck_ports.h"
#include "e_uart_char.h"
#include "memory.h" /* include only if constants for memory layout are requested */

/******************************************************************************/
/* Global Variable Declaration                                                */
/******************************************************************************/

char buffer[BUFFER_SIZE]; //__attribute__ ((__far__));


/******************************************************************************/
/* Utility Functions                                                           */
/******************************************************************************/

void wait(long num) {
  long i;
  for(i=0;i<num;i++);
}

int getselector() {
  return SELECTOR0 + 2*SELECTOR1 + 4*SELECTOR2 + 8*SELECTOR3;
}


/******************************************************************************/
/* Main Program                                                               */
/******************************************************************************/

int main(void)
{
    int selector;

    /* Initialize IO ports and motors */
    e_init_port();    // configure port pins
    e_start_agendas_processing(); // needed for timing the stepping motors
    e_init_motors(); 
    e_init_uart1();   // initialize UART to 115200 Kbaud

    e_init_ad_scan(ALL_ADC);
    //e_init_ad_scan();

    // Read selector and send to bluetooth console
    // The selector is a rotary knob on the top of the e-puck.
    selector=getselector();
    sprintf(buffer, "Selector pos %d\r\n", selector);
    e_send_uart1_char(buffer, strlen(buffer));
    
    if (selector==0)
    {
        while (1)
        {
            e_set_led(8, 1);  // switch all leds on
            wait(150000);
            e_set_led(8, 0);  // switch all leds on
            wait(150000);
        }
    }
    
    
    // TODO: Enter your code here
    

    if (selector<=8)
    {
        e_set_led(selector, 1);
    }

    if (selector==9)
    {
        e_set_speed_left(800);
        e_set_speed_right(800);
        wait(1500000);
        e_set_speed_left(0);
        e_set_speed_right(0);
    }

    while(1) // prevents restart of the robot
    {

    }
}